@@ -23,7 +23,7 @@ docs = [
 ]
 
 doc_store = InMemoryDocumentStore(embedding_similarity_function="cosine")
-doc_embedder = SentenceTransformersDocumentEmbedder(model_name_or_path="sentence-transformers/all-MiniLM-L6-v2")
+doc_embedder = SentenceTransformersDocumentEmbedder(model="sentence-transformers/all-MiniLM-L6-v2")
 
 
 # Indexing Pipeline
@@ -47,7 +47,7 @@ GPT4 Correct Assistant:
 """
 rag_pipeline = Pipeline()
 
-text_embedder = SentenceTransformersTextEmbedder(model_name_or_path="sentence-transformers/all-MiniLM-L6-v2")
+text_embedder = SentenceTransformersTextEmbedder(model="sentence-transformers/all-MiniLM-L6-v2")
 
 model_path = "openchat-3.5-1210.Q3_K_S.gguf"
 generator = LlamaCppGenerator(model_path=model_path, n_ctx=4096, n_batch=128)
